### ----------------------------------------
### Tick-density model Rstanarm
### NPS tick drag data 2014-2022
### Code created by A. Martin
### Email: alynn.martin89@gmail.com
### ----------------------------------------
### MODEL01


### L O A D   P A C K A G E S

library(rstanarm)
library(rstan)
library(bayesrules)
library(tidyverse)
library(bayesplot)
library(tidybayes)



### L O A D  D A T A

 data01 <- read.table(file="XXX.txt")  ## load tabular data using download name
 
 
 
### M O D E L  01

stan_mod01 <- stan_glmer(
  
  count ~ phdd + relative_humidity_april + (1|park_id) + lagged_deer_density,              
  
  data = data01, 
  
  family = neg_binomial_2(link="log"), 
  
  prior_intercept = normal(0,2.0),
  
  prior = normal(0, 2.0), 
  
  prior_covariance = decov(reg = 1, conc = 1, shape = 1, scale = 1),
  
  importance_resampling=TRUE, keep_every=10,

  chains = 3, iter = 30000*2, seed = 1000
  
)



###  M O D E L   O U T P U T

## summary

summary(stan_mod01)

coef(stan_mod01)

stan_mod01$coefficients

tidy(stan_mod01, effects = "fixed", conf.int = TRUE, conf.level = 0.95)

tidy(stan_mod01, effects = "ran_vals", conf.int = TRUE, conf.level = 0.95)


## trace plots

trace <- plot(stan_mod01, "trace", pars=(c("(Intercept)", "phdd", "relative_humidity_april", "lagged_deer_density")))


## plotting fixed variable effect

plot(stan_mod01, pars =c("(Intercept)", "phdd", "relative_humidity_april", "lagged_deer_density"), prob=0.5, prob_outer=0.95)

